=======================================
Djangoflow REST Authentication with JWT
=======================================

Opinionated Django REST auth endpoints for JWT authentication and social accounts.
